使用Roaring位图提高位图性能
Better bitmap performance with Roaring bitmaps
摘要:
位图索引通常用于数据库和搜索引擎。通过利用位级并行性,它们可以显着加速查询。然而,它们可能会使用大量内存,因此我们可能更喜欢压缩的位图索引。在Oracle的领导下,位图通常使用行程长度编码(RLE)进行压缩。在之前工作的基础上,我们引入了Roaring压缩位图格式:它使用压缩数组而不是RLE进行压缩。我们将其与两种高性能的基于RLE的位图编码技术进行比较:WAH(字对齐混合压缩方案)和Concise(压缩的n可组合位图集)。在合成和真实数据上,我们发现咆哮位图(1)通常压缩得更好(例如,2倍)和(2)比压缩的替代方案快(交叉点快900倍)。我们的研究结果挑战了基于RLE的位图压缩是最好的观点。
英文摘要:
Bitmap indexes are commonly used in databases and search engines. By exploiting bit-level parallelism, they can significantly accelerate queries. However, they can use much memory, and thus we might prefer compressed bitmap indexes. Following Oracle's lead, bitmaps are often compressed using run-length encoding (RLE). Building on prior work, we introduce the Roaring compressed bitmap format: it uses packed arrays for compression instead of RLE. We compare it to two high-performance RLE-based bitmap encoding techniques: WAH (Word Aligned Hybrid compression scheme) and Concise (Compressed `n' Composable Integer Set). On synthetic and real data, we find that Roaring bitmaps (1) often compress significantly better (e.g., 2 times) and (2) are faster than the compressed alternatives (up to 900 times faster for intersections). Our results challenge the view that RLE-based bitmap compression is best.
机构、总结、中文摘要均由AI分析而来,可能存在错误,请以论文正文为准。